@@ -25,6 +25,20 @@ ADPclustering=function(Data,ClusterNo=NULL,PlotIt=FALSE,...){
     )
   }
   
+  if (!requireNamespace('cluster', quietly = TRUE)) {
+    message(
+      'Subordinate clustering package (cluster) is missing although its imported in ADPclust. No computations are performed.
+            Please install the package which is defined in "Suggests".'
+    )
+    return(
+      list(
+        Cls = rep(1, nrow(Data)),
+        Object = "Subordinate clustering package (cluster) is missing  although its imported in ADPclust.
+                Please install the package which is defined in 'Suggests'."
+      )
+    )
+  }
+  
   if(is.null(ClusterNo))
 	adp=ADPclust::adpclust(Data,...)
   else
